Transition<E extends StateMachineEvent<Object, Object> , S extends StateMachineState<Object> > class
final
A state machine transition from one state to the next.
- Mixed-in types
-
- AWSEquatable<
Transition< E, S> > - AWSDebuggable
- AWSEquatable<
- Annotations
Constructors
- Transition(S previousState, E event, S nextState)
-
A state machine transition from one state to the next.
const
Properties
- event → E
-
The event which triggered the change.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextState → S
-
The next (current) state.
final
- previousState → S
-
The previous state.
final
-
props
→ List<
Object?> -
The type's equatable properties.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- runtimeTypeName → String
-
The string value of runtimeType, saving a runtime lookup and preventing
obfuscation during web compilation.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited